==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/so-SO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Xaqiiji Tirtir Hantida Badan',
    'bulk_restore'      => 'Xaqiiji Hanti Soo Celinta Bulk', 
  'bulk_delete_help'	=> 'Hoos ku eeg hantida tirtirka badan Marka la tirtiro, hantidan waa la soo celin karaa, laakiin hadda ka dib lama xidhiidhin doono isticmaale kasta oo hadda loo qoondeeyey.',
  'bulk_restore_help'	=> 'Hoos ku eeg hantida dib u soo celinta tirada badan. Marka dib loo soo celiyo, hantidan lalama xidhiidhin doono isticmaaleyaal hore loogu qoondeeyey.',
  'bulk_delete_warn'	=> 'Waxaad ku dhowdahay inaad tirtirto :asset_count hantida.',
  'bulk_restore_warn'	=> 'Waxaad soo celinaysaa :asset_count hantida.',
    'bulk_update'		=> 'Hantida Cusbooneysii Badan',
    'bulk_update_help'	=> 'Foomkan wuxuu kuu ogolaanayaa inaad hal mar cusboonaysiiso hanti badan. Kaliya buuxi meelaha aad u baahan tahay inaad bedesho. Goob kasta oo bannaan ayaa ahaan doonta mid aan isbeddelin. ',
    'bulk_update_warn'	=> 'Waxaad ku dhowdahay inaad wax ka beddesho sifooyinka hanti keli ah.|Waxaad ku dhowdahay inaad wax ka beddesho guryaha :asset_count hantida.',
    'bulk_update_with_custom_field' => 'Ogow hantidu waa :asset_model_count noocyo noocyo kala duwan ah.',
    'bulk_update_model_prefix' => 'Qaababka', 
    'bulk_update_custom_field_unique' => 'Tani waa goob gaar ah oo aan la tafatirin karin.',
    'checkedout_to'		=> 'La Hubiyay',
    'checkout_date'		=> 'Taariikhda Bixinta',
    'checkin_date'		=> 'Taariikhda la soo galayo',
    'checkout_to'		=> 'Iska hubi',
    'cost'				=> 'Qiimaha iibka',
    'create'			=> 'Abuur Hanti',
    'date'				=> 'Taariikhda Iibka',
    'depreciation'	    => 'Qiimo dhaca',
    'depreciates_on'	=> 'Qiimo dhaca On',
    'default_location'	=> 'Goobta ugu talagalka ah',
    'default_location_phone' => 'Taleefanka Goobta ugu tala galay',
    'eol_date'			=> 'Taariikhda EOL',
    'eol_rate'			=> 'Heerka EOL',
    'expected_checkin'  => 'Taariikhda la filayo',
    'expires'			=> 'Dhacaya',
    'fully_depreciated'	=> 'Si Buuxda U Dhacay',
    'help_checkout'		=> 'Haddii aad rabto in aad si degdeg ah u qoondayso hantidan, ka dooro "Diyaar u ah in la geeyo" liiska xaaladda kore. ',
    'mac_address'		=> 'Cinwaanka MAC',
    'manufacturer'		=> 'Soo saaraha',
    'model'				=> 'Qaabka',
    'months'			=> 'bilo',
    'name'				=> 'Magaca Hantida',
    'notes'				=> 'Xusuusin',
    'order'				=> 'Nambarka dalbashada',
    'qr'				=> 'Koodhka QR',
    'requestable'		=> 'Isticmaalayaasha ayaa codsan kara hantidan',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Dooro Nooca Xaaladda',
    'serial'			=> 'Taxane',
    'status'			=> 'Xaalada',
    'tag'				=> 'Hantida Tag',
    'update'			=> 'Cusboonaysiinta Hantida',
    'warranty'			=> 'Dammaanad',
        'warranty_expires'		=> 'Dammaanadku Wuu Dhacayaa',
    'years'				=> 'sanado',
    'asset_location' => 'Cusbooneysii Goobta Hantida',
    'asset_location_update_default_current' => 'Cusbooneysii goobta caadiga ah IYO goobta dhabta ah',
    'asset_location_update_default' => 'Cusbooneysii kaliya goobta caadiga ah',
    'asset_location_update_actual' => 'Cusbooneysii goobta dhabta ah oo kaliya',
    'asset_not_deployable' => 'Heerka hantidu maaha mid la diri karo Hantidan lama hubin karo.',
    'asset_deployable' => 'Heerkaas waa la geyn karaa Hantidan waa la hubin karaa.',
    'processing_spinner' => 'Hagaajinta... (Tani waxa laga yaabaa inay wakhti yar ku qaadato faylalka waaweyn)',
    'optional_infos'  => 'Macluumaadka Ikhtiyaarka ah',
    'order_details'   => 'Dalbo Macluumaadka La Xiriira'
];

==> snipe-it-7.0.13.zip: snipe-it-7.0.13/resources/lang/so-SO/admin/hardware/form.php <==
<?php

return [
    'bulk_delete'		=> 'Xaqiiji Tirtir Hantida Badan',
    'bulk_restore'      => 'Xaqiiji Hanti Soo Celinta Bulk', 
  'bulk_delete_help'	=> 'Hoos ku eeg hantida tirtirka badan Marka la tirtiro, hantidan waa la soo celin karaa, laakiin hadda ka dib lama xidhiidhin doono isticmaale kasta oo hadda loo qoondeeyey.',
  'bulk_restore_help'	=> 'Hoos ku eeg hantida dib u soo celinta tirada badan. Marka dib loo soo celiyo, hantidan lalama xidhiidhin doono isticmaaleyaal hore loogu qoondeeyey.',
  'bulk_delete_warn'	=> 'Waxaad ku dhowdahay inaad tirtirto :asset_count hantida.',
  'bulk_restore_warn'	=> 'Waxaad soo celinaysaa :asset_count hantida.',
    'bulk_update'		=> 'Hantida Cusbooneysii Badan',
    'bulk_update_help'	=> 'Foomkan wuxuu kuu ogolaanayaa inaad hal mar cusboonaysiiso hanti badan. Kaliya buuxi meelaha aad u baahan tahay inaad bedesho. Goob kasta oo bannaan ayaa ahaan doonta mid aan isbeddelin. ',
    'bulk_update_warn'	=> 'Waxaad ku dhowdahay inaad wax ka beddesho sifooyinka hanti keli ah.|Waxaad ku dhowdahay inaad wax ka beddesho guryaha :asset_count hantida.',
    'bulk_update_with_custom_field' => 'Ogow hantidu waa :asset_model_count noocyo noocyo kala duwan ah.',
    'bulk_update_model_prefix' => 'Qaababka', 
    'bulk_update_custom_field_unique' => 'Tani waa goob gaar ah oo aan la tafatirin karin.',
    'checkedout_to'		=> 'La Hubiyay',
    'checkout_date'		=> 'Taariikhda Bixinta',
    'checkin_date'		=> 'Taariikhda la soo galayo',
    'checkout_to'		=> 'Iska hubi',
    'cost'				=> 'Qiimaha iibka',
    'create'			=> 'Abuur Hanti',
    'date'				=> 'Taariikhda Iibka',
    'depreciation'	    => 'Qiimo dhaca',
    'depreciates_on'	=> 'Qiimo dhaca On',
    'default_location'	=> 'Goobta ugu talagalka ah',
    'default_location_phone' => 'Taleefanka Goobta ugu tala galay',
    'eol_date'			=> 'Taariikhda EOL',
    'eol_rate'			=> 'Heerka EOL',
    'expected_checkin'  => 'Taariikhda la filayo',
    'expires'			=> 'Dhacaya',
    'fully_depreciated'	=> 'Si Buuxda U Dhacay',
    'help_checkout'		=> 'Haddii aad rabto in aad si degdeg ah u qoondayso hantidan, ka dooro "Diyaar u ah in la geeyo" liiska xaaladda kore. ',
    'mac_address'		=> 'Cinwaanka MAC',
    'manufacturer'		=> 'Soo saaraha',
    'model'				=> 'Qaabka',
    'months'			=> 'bilo',
    'name'				=> 'Magaca Hantida',
    'notes'				=> 'Xusuusin',
    'order'				=> 'Nambarka dalbashada',
    'qr'				=> 'Koodhka QR',
    'requestable'		=> 'Isticmaalayaasha ayaa codsan kara hantidan',
    'redirect_to_all'   => 'Return to all :type',
    'redirect_to_type'   => 'Go to :type',
    'redirect_to_checked_out_to'   => 'Go to Checked Out to',
    'select_statustype'	=> 'Dooro Nooca Xaaladda',
    'serial'			=> 'Taxane',
    'status'			=> 'Xaalada',
    'tag'				=> 'Hantida Tag',
    'update'			=> 'Cusboonaysiinta Hantida',
    'warranty'			=> 'Dammaanad',
        'warranty_expires'		=> 'Dammaanadku Wuu Dhacayaa',
    'years'				=> 'sanado',
    'asset_location' => 'Cusbooneysii Goobta Hantida',
    'asset_location_update_default_current' => 'Cusbooneysii goobta caadiga ah IYO goobta dhabta ah',
    'asset_location_update_default' => 'Cusbooneysii kaliya goobta caadiga ah',
    'asset_location_update_actual' => 'Cusbooneysii goobta dhabta ah oo kaliya',
    'asset_not_deployable' => 'Heerka hantidu maaha mid la diri karo Hantidan lama hubin karo.',
    'asset_not_deployable_checkin' => 'That asset status is not deployable. Using this status label will checkin the asset.',
    'asset_deployable' => 'Heerkaas waa la geyn karaa Hantidan waa la hubin karaa.',
    'processing_spinner' => 'Hagaajinta... (Tani waxa laga yaabaa inay wakhti yar ku qaadato faylalka waaweyn)',
    'optional_infos'  => 'Macluumaadka Ikhtiyaarka ah',
    'order_details'   => 'Dalbo Macluumaadka La Xiriira'
];
